package com.example.wendelyn.test2;

import android.Manifest;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationManager;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.Toast;

/**
 * Created by Wendelyn on 3/2/2016.
 */
public class GeofenceActivity extends AppCompatActivity{
    private static final String RADIUS = "radius_geofence_WW";
    private static final String LONGITUDE = "long_geofence_WW";
    private static final String LATITUDE = "lati_geofence_WW";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.geofence_page);

        //Set up the radius selection spinner
        final Spinner radiusSpinner = (Spinner) findViewById(R.id.radiusSelect);
        ArrayAdapter<CharSequence> staticAdapter = ArrayAdapter
                .createFromResource(this, R.array.radius_array,
                        android.R.layout.simple_spinner_item);
        staticAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        radiusSpinner.setAdapter(staticAdapter);

        //To get the current location and set it to the geofence center.
        LocationManager locationManager;
        locationManager = (LocationManager) getSystemService(LOCATION_SERVICE);
        Criteria criteria = new Criteria();
        String provider = locationManager.getBestProvider(criteria, false);
        final Location location = locationManager.getLastKnownLocation(provider);
        if (ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED && ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            // If permission has not been granted
            return;
        }

        //Save the radius and move on to the main menu when done.
        View.OnClickListener okListen = new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //Save the radius and current location to preferences
                SharedPreferences.Editor editor = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE).edit();
                int selectedPosition = radiusSpinner.getSelectedItemPosition();
                editor.putInt(RADIUS, selectedPosition);

                if (location != null){
                    editor.putLong(LONGITUDE, Double.doubleToRawLongBits(location.getLongitude()));
                    editor.putLong(LATITUDE, Double.doubleToRawLongBits(location.getLatitude()));
                } else {
                    double defaultLati = 28.600615;
                    double defaultLong = -81.197612;
                    editor.putLong(LONGITUDE, Double.doubleToRawLongBits(defaultLong));
                    editor.putLong(LATITUDE, Double.doubleToRawLongBits(defaultLati));
                }

                editor.commit();

                Intent myIntent = new Intent(GeofenceActivity.this, MainActivity.class);
                GeofenceActivity.this.startActivity(myIntent);
            }
        };
        Button okBtn = (Button) findViewById(R.id.okButton);
        okBtn.setOnClickListener(okListen);

        //When cancelling on this page, it should delete the user preferences.
        View.OnClickListener cancelListen = new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                SharedPreferences.Editor deletePrefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE).edit();
                deletePrefs.clear().commit();

                finish();
                Intent myIntent = new Intent(GeofenceActivity.this, LoginActivity.class);
                GeofenceActivity.this.startActivity(myIntent);
            }
        };
        Button cancelBtn = (Button) findViewById(R.id.cancelButton);
        cancelBtn.setOnClickListener(cancelListen);
    }
}
