package com.example.wendelyn.test2;

import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.database.Cursor;
import android.graphics.Color;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.support.v7.app.AppCompatActivity;
import android.telephony.SmsManager;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.CircleOptions;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

/**
 * Created by Wendelyn on 12/14/2015.
 */
public class MapActivity extends AppCompatActivity implements OnMapReadyCallback {
    private static final String RADIUS = "radius_geofence_WW";
    private static final String LONGITUDE = "long_geofence_WW";
    private static final String LATITUDE = "lati_geofence_WW";
    private static final String USERNAME = "username_WW";
    private static final String WATCHID= "watch_number_WW";

    private GoogleMap mMap;

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.map_page);

        final SharedPreferences prefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE);
        if (prefs.getString(USERNAME,"").equals("")) {
            finish();
            Intent myIntent = new Intent(MapActivity.this, LoginActivity.class);
            MapActivity.this.startActivity(myIntent);
        }

        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);

        View.OnClickListener goBack = new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                finish();
                Intent myIntent = new Intent(MapActivity.this, MainActivity.class);
                MapActivity.this.startActivity(myIntent);
            }
        };
        Button goBtn = (Button) findViewById(R.id.goButton);
        goBtn.setOnClickListener(goBack);

        View.OnClickListener refreshMap = new View.OnClickListener(){
            @Override
            public void onClick(View v) {
                //Refresh the map if the watch is wandering
                refreshWWMap();
            }
        };
        Button refreshBtn = (Button) findViewById(R.id.refreshButton);
        refreshBtn.setOnClickListener(refreshMap);
    }

    /**
     * Manipulates the map once available.
     * This callback is triggered when the map is ready to be used.
     * This is where we can add markers or lines, add listeners or move the camera. In this case,
     * we just add a marker near Sydney, Australia.
     * If Google Play services is not installed on the device, the user will be prompted to install
     * it inside the SupportMapFragment. This method will only be triggered once the user has
     * installed Google Play services and returned to the app.
     */
    @Override
    public void onMapReady(GoogleMap googleMap) {
        mMap = googleMap;

        boolean checkWatch = false;

        ContentResolver contentResolver = getContentResolver();
        Cursor smsInboxCursor = contentResolver.query(Uri.parse("content://sms/inbox"), null, null, null, null);
        int indexBody = smsInboxCursor.getColumnIndex("body");
        int indexAddress = smsInboxCursor.getColumnIndex("address");

        final SharedPreferences prefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE);
        String watchNumber = "";
        if (prefs.getString(WATCHID,"").equals("")){
            checkWatch = true;
        } else {
            watchNumber = "+1" + prefs.getString(WATCHID,""); // +1 must be added to phone numbers to show the right ones.
        }

        if (!checkWatch){
            do {
                smsInboxCursor.moveToNext();
            } while (!(smsInboxCursor.getString(indexAddress)).equals(watchNumber));
        }

        double geoLong = Double.longBitsToDouble(prefs.getLong(LONGITUDE, 0));
        double geoLati = Double.longBitsToDouble(prefs.getLong(LATITUDE, 0));
        double geoRadius = ((prefs.getInt(RADIUS, 0)) + 1) * 10 ;

        LatLng geofenceLocation = new LatLng(geoLati, geoLong);

        //If there is no watch detected, or if there is no wandering, just show the geofence home.
        if (checkWatch || !smsInboxCursor.getString(indexBody).contains("wandering")){
            mMap.addMarker(new MarkerOptions().position(geofenceLocation).title("Wander Watch"));
            mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(geofenceLocation, 14));
        } else{ //Otherwise, show the marker with the updated watch location.
            //Getting the string of numbers that represent the latitude first.
            String watchMLati = smsInboxCursor.getString(indexBody).substring(
                    smsInboxCursor.getString(indexBody).indexOf("Latitude: ") + 1,
                    smsInboxCursor.getString(indexBody).indexOf(","));

            watchMLati = watchMLati.replaceAll("[^\\d.-]",""); //Clearing any extraneous characters just in case.

            //Getting the string of numbers that are the longitude.
            String watchMLong = smsInboxCursor.getString(indexBody).substring(
                    smsInboxCursor.getString(indexBody).indexOf("Longitude: ") + 1);

            watchMLong = watchMLong.replaceAll("[^\\d.-]","");

            double watchLong = Double.parseDouble(watchMLong);
            double watchLati = Double.parseDouble(watchMLati);

            LatLng watchLocation = new LatLng(watchLati, watchLong);
            mMap.addMarker(new MarkerOptions().position(watchLocation).title("Wander Watch"));
            mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(watchLocation, 14));
        }

        CircleOptions circleOptions = new CircleOptions()
                .center( geofenceLocation ) //Replace with home latitude and longitude
                .radius( geoRadius ) //Replace with geofence radius
                .fillColor(0x40ff0000)
                .strokeColor(Color.TRANSPARENT)
                .strokeWidth(2);

        mMap.addCircle(circleOptions);

    }

    protected void refreshWWMap(){
        final SharedPreferences prefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE);
        /* Log.i("Send SMS", "");
        String phoneNo = "+1" + prefs.getString(WATCHID,""); //It needs the +1 to work
        String message = "location";

        SmsManager smsManager = SmsManager.getDefault();
        smsManager.sendTextMessage(phoneNo, null, message, null, null); */

        //NOTE: If the watch is not wandering, the latest message in the messages should say "watch is at home"
        // If it is wandering, it will have the key word in it.

        Handler handler = new Handler();
        handler.postDelayed(new Runnable() {
            @Override
            public void run() {
                // Do the following after 5 seconds. This allows for time to receive the new message from the watch.
                ContentResolver contentResolver = getContentResolver();
                Cursor smsInboxCursor = contentResolver.query(Uri.parse("content://sms/inbox"), null, null, null, null);
                int indexBody = smsInboxCursor.getColumnIndex("body");
                int indexAddress = smsInboxCursor.getColumnIndex("address");

                String watchNumber;
                if (prefs.getString(WATCHID,"").equals("")){
                    Toast.makeText(getApplicationContext(), "No watch number found.", Toast.LENGTH_LONG).show();
                    return;
                } else {
                    watchNumber = "+1" + prefs.getString(WATCHID,""); // +1 must be added to phone numbers to show the right ones.
                }

                //Check the latest message if the watch is wandering, set up the marker accordingly
                do {
                    smsInboxCursor.moveToNext();
                } while (!(smsInboxCursor.getString(indexAddress)).equals(watchNumber));

                if (!smsInboxCursor.getString(indexBody).contains("wandering")){
                    Toast.makeText(getApplicationContext(), "No wandering detected.", Toast.LENGTH_LONG).show();
                } else{
                    Toast.makeText(getApplicationContext(), "Wandering!!", Toast.LENGTH_LONG).show();

                    //Getting the string of numbers that represent the latitude first.
                    String watchMLati = smsInboxCursor.getString(indexBody).substring(
                            smsInboxCursor.getString(indexBody).indexOf("Latitude: ") + 1,
                            smsInboxCursor.getString(indexBody).indexOf(","));

                    watchMLati = watchMLati.replaceAll("[^\\d.-]",""); //Clearing any extraneous characters just in case.

                    //Getting the string of numbers that are the longitude.
                    String watchMLong = smsInboxCursor.getString(indexBody).substring(
                            smsInboxCursor.getString(indexBody).indexOf("Longitude: ") + 1);

                    watchMLong = watchMLong.replaceAll("[^\\d.-]","");

                    double watchLong = Double.parseDouble(watchMLong);
                    double watchLati = Double.parseDouble(watchMLati);

                    mMap.clear();
                    double geoLong = Double.longBitsToDouble(prefs.getLong(LONGITUDE, 0));
                    double geoLati = Double.longBitsToDouble(prefs.getLong(LATITUDE, 0));
                    double geoRadius = ((prefs.getInt(RADIUS, 0)) + 1) * 10 ;

                    LatLng geofenceLocation = new LatLng(geoLati, geoLong);
                    LatLng watchLocation = new LatLng(watchLati, watchLong);

                    mMap.addMarker(new MarkerOptions().position(watchLocation).title("Wander Watch"));
                    mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(watchLocation, 14));

                    CircleOptions circleOptions = new CircleOptions()
                            .center( geofenceLocation ) //Replace with home latitude and longitude
                            .radius( geoRadius ) //Replace with geofence radius
                            .fillColor(0x40ff0000)
                            .strokeColor(Color.TRANSPARENT)
                            .strokeWidth(2);

                    mMap.addCircle(circleOptions);
                }

            }
        }, 1000); //5000 = 5 second delay, 1000 = 1 second delay
    }
}
