package com.example.wendelyn.test2;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.telephony.SmsManager;
import android.util.Log;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.Spinner;
import android.widget.Toast;

/**
 * Created by Wendelyn on 12/14/2015.
 */
public class SettingsActivity extends AppCompatActivity {
    private static final String FREQUENCY = "frequency_check_WW";
    private static final String TIMESPAN = "time_spinner_WW";
    private static final String BATTERY = "battery_check_WW";
    private static final String RADIUS = "radius_geofence_WW";
    private static final String USERNAME = "username_WW";
    private static final String WATCHID= "watch_number_WW";

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.settings_page);

        final SharedPreferences prefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE);
        if (prefs.getString(USERNAME,"").equals("")){
            //Go back to the login screen, because there is no user data.
            finish();
            Intent myIntent = new Intent(SettingsActivity.this, LoginActivity.class);
            SettingsActivity.this.startActivity(myIntent);
        }

        final Spinner frequencySpinner = (Spinner) findViewById(R.id.frequencySelect);

        // Create an ArrayAdapter using the string array and a default spinner
        ArrayAdapter<CharSequence> staticAdapter = ArrayAdapter
                .createFromResource(this, R.array.frequency_array,
                        android.R.layout.simple_spinner_item);

        // Specify the layout to use when the list of choices appears
        staticAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);

        // Apply the adapter to the spinner
        frequencySpinner.setAdapter(staticAdapter);

        //Same process for the radius selection
        final Spinner radiusSpinner = (Spinner) findViewById(R.id.radiusSelect);
        staticAdapter = ArrayAdapter
                .createFromResource(this, R.array.radius_array,
                        android.R.layout.simple_spinner_item);

        radiusSpinner.setAdapter(staticAdapter);

        //Alert for deleting user's account
        final AlertDialog deleteAlert = new AlertDialog.Builder(SettingsActivity.this).create();
        deleteAlert.setTitle("Delete Account");
        deleteAlert.setMessage("Are you sure?");
        deleteAlert.setButton(DialogInterface.BUTTON_POSITIVE, "Yes", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                deleteAlert.hide();
                deleteAccount();
            }
        });
        deleteAlert.setButton(DialogInterface.BUTTON_NEGATIVE, "No", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                deleteAlert.hide();
            }
        });

        View.OnClickListener deleteAcc = new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                deleteAlert.show();
            }
        };
        Button deleteBtn = (Button) findViewById(R.id.deleteButton);
        deleteBtn.setOnClickListener(deleteAcc);

        //Alert for changing the watch
        final AlertDialog changeAlert = new AlertDialog.Builder(SettingsActivity.this).create();
        changeAlert.setTitle("Change Watch");
        changeAlert.setMessage("Are you sure you want to change your watch?");
        changeAlert.setButton(DialogInterface.BUTTON_POSITIVE, "Yes", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                changeAlert.hide();
                deletePhone(); //Delete the phone number from the old watch to be able to save a new one.
                prefs.edit().remove(WATCHID).commit();

                Intent myIntent = new Intent(SettingsActivity.this, WatchActivity.class);
                SettingsActivity.this.startActivity(myIntent);
            }
        });
        changeAlert.setButton(DialogInterface.BUTTON_NEGATIVE, "No", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                changeAlert.hide();
            }
        });

        View.OnClickListener changeWatch = new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                changeAlert.show();
            }
        };
        Button changeBtn = (Button) findViewById(R.id.changeButton);
        changeBtn.setOnClickListener(changeWatch);

        final CheckBox freqCheck = (CheckBox)findViewById(R.id.autoBox);
        final CheckBox batteryCheck = (CheckBox)findViewById(R.id.batteryBox);

        freqCheck.setChecked(prefs.getBoolean(FREQUENCY, true));
        frequencySpinner.setSelection(prefs.getInt(TIMESPAN, 0));
        frequencySpinner.setEnabled(freqCheck.isChecked());
        batteryCheck.setChecked(prefs.getBoolean(BATTERY, true));
        radiusSpinner.setSelection(prefs.getInt(RADIUS, 0));

        freqCheck.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                frequencySpinner.setEnabled(freqCheck.isChecked());
            }
        });

        View.OnClickListener goBack = new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String messageString;
                Integer changed = 0;

                //Save settings to file
                SharedPreferences.Editor editor = prefs.edit();
                int selectedPosition = frequencySpinner.getSelectedItemPosition();
                if (prefs.getInt(TIMESPAN, 0) != selectedPosition){
                    editor.putInt(TIMESPAN, selectedPosition);
                    changed++;
                } messageString = TIMESPAN + ": " + selectedPosition + ", ";

                boolean checked = freqCheck.isChecked();
                if (prefs.getBoolean(FREQUENCY, true) != checked){
                    editor.putBoolean(FREQUENCY, checked);
                    changed++;
                } messageString = messageString + FREQUENCY + ": " + checked + ", ";

                checked = batteryCheck.isChecked();
                if (prefs.getBoolean(BATTERY, true) != checked){
                    editor.putBoolean(BATTERY, checked);
                    changed++;
                } messageString = messageString + BATTERY + ": " + checked + ", ";

                selectedPosition = radiusSpinner.getSelectedItemPosition();
                if (prefs.getInt(RADIUS, 0) != selectedPosition){
                    editor.putInt(RADIUS, selectedPosition);
                    changed++;
                } messageString = messageString + RADIUS + ": " + selectedPosition + ".";

                editor.apply();

                //Save settings to the phone only if changes were made.
                if (changed > 0){ sendSMSMessage(messageString); }

                finish();
                Intent myIntent = new Intent(SettingsActivity.this, MainActivity.class);
                SettingsActivity.this.startActivity(myIntent);
            }
        };
        Button goBtn = (Button) findViewById(R.id.goButton);
        goBtn.setOnClickListener(goBack);
    }

    protected void sendSMSMessage(String messageString) {
        final SharedPreferences prefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE);
        Log.i("Send SMS", "");
        String phoneNo = "+1" + prefs.getString(WATCHID,"");

        try {
            SmsManager smsManager = SmsManager.getDefault();
            smsManager.sendTextMessage(phoneNo, null, messageString, null, null);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void deleteAccount(){
        //Send message to watch to delete phone number.
        deletePhone(); //This is sent before clearing the preferences, to get access to the
                       //watch's number one last time before deletion.

        SharedPreferences.Editor deletePrefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE).edit();
        deletePrefs.clear().commit();

        finish();
        Intent myIntent = new Intent(SettingsActivity.this, LoginActivity.class);
        SettingsActivity.this.startActivity(myIntent);
    }

    protected void deletePhone(){
        final SharedPreferences prefs = getSharedPreferences("com.example.wendelyn.test2", Context.MODE_PRIVATE);
        Log.i("Send SMS", "");
        String phoneNo = "+1" + prefs.getString(WATCHID,"");

        try {
            SmsManager smsManager = SmsManager.getDefault();
            smsManager.sendTextMessage(phoneNo, null, "Delete phone", null, null);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }
}
